@@ -33,11 +33,15 @@ class _WpSendData:
     def set(self, result: bool) -> None:
         """Socket send result"""
         self._result = result
+
         if not self._complete.is_set():
             self._complete.set()
 
     async def wait(self) -> bool:
         """Socket send wait"""
+        if self._complete.is_set():
+            self._complete.clear()
+
         await self._complete.wait()
         return self._result
 
